@@ -192,10 +192,10 @@ class Testbed:
             cpu_info = self.check_exec(['sh', '-c', 'nproc; cat /proc/cpuinfo 2>/dev/null || true'],
                                        stdout=True).strip()
             self.nproc = cpu_info.split('\n', 1)[0]
-            m = re.search('^(model.*name|cpu)\s*:\s*(.*)$', cpu_info, re.MULTILINE | re.IGNORECASE)
+            m = re.search(r'^(model.*name|cpu)\s*:\s*(.*)$', cpu_info, re.MULTILINE | re.IGNORECASE)
             if m:
                 self.cpu_model = m.group(2)
-            m = re.search('^(flags|features)\s*:\s*(.*)$', cpu_info, re.MULTILINE | re.IGNORECASE)
+            m = re.search(r'^(flags|features)\s*:\s*(.*)$', cpu_info, re.MULTILINE | re.IGNORECASE)
             if m:
                 self.cpu_flags = m.group(2)
 
@@ -303,7 +303,7 @@ class Testbed:
         for pocket in self.add_apt_pockets:
             pocket = pocket.split('=', 1)[0]  # strip off package list
             script = '''
-            sed -rn 's/^(deb|deb-src) +(\[.*\] *)?((http|https|file):[^ ]*) +([^ -]+) +(.*)$/\\1 \\2\\3 \\5-%s \\6/p' \\
+            sed -rn 's/^(deb|deb-src) +(\\[.*\\] *)?((http|https|file):[^ ]*) +([^ -]+) +(.*)$/\\1 \\2\\3 \\5-%s \\6/p' \\
                 /etc/apt/sources.list `ls /etc/apt/sources.list.d/*.list 2>/dev/null|| true` > \\
                 /etc/apt/sources.list.d/%s.list
             for retry in 1 2 3; do
@@ -331,7 +331,7 @@ class Testbed:
                                                   [self._get_default_release() + '-updates'])
         if self.add_apt_releases:
             get_mirror_and_components = '''
-            sed -rn 's/^(deb|deb-src) +(\[.*\] *)?((http|https|file):[^ ]*) +([^ -]+) +(.*)$/\\2\\3 \\6/p' \\
+            sed -rn 's/^(deb|deb-src) +(\\[.*\\] *)?((http|https|file):[^ ]*) +([^ -]+) +(.*)$/\\2\\3 \\6/p' \\
                 /etc/apt/sources.list `ls /etc/apt/sources.list.d/*.list 2>/dev/null|| true` | head -1
             '''
             mirror_and_components = self.check_exec(['sh', '-ec', get_mirror_and_components], stdout=True).split()
@@ -352,7 +352,7 @@ class Testbed:
         # record the mtimes of dirs affecting the boot
         boot_dirs = '/boot /etc/init /etc/init.d /etc/systemd/system /lib/systemd/system'
         self.check_exec(['bash', '-ec',
-                         'for d in %s; do [ ! -d $d ] || touch -r $d %s/${d//\//_}.stamp; done' % (
+                         r'for d in %s; do [ ! -d $d ] || touch -r $d %s/${d//\//_}.stamp; done' % (
                              boot_dirs, self.scratch)])
 
         xenv = ['AUTOPKGTEST_IS_SETUP_COMMAND=1']
@@ -373,9 +373,9 @@ class Testbed:
         # if the setup commands affected the boot, then reboot
         if self.setup_commands and 'reboot' in self.caps:
             boot_affected = self.execute(
-                ['bash', '-ec', '[ ! -e /run/autopkgtest_no_reboot.stamp ] || exit 0;'
-                 'for d in %s; do s=%s/${d//\//_}.stamp;'
-                 '  [ ! -d $d ] || [ `stat -c %%Y $d` = `stat -c %%Y $s` ]; done' % (
+                ['bash', '-ec', r'[ ! -e /run/autopkgtest_no_reboot.stamp ] || exit 0;'
+                 r'for d in %s; do s=%s/${d//\//_}.stamp;'
+                 r'  [ ! -d $d ] || [ `stat -c %%Y $d` = `stat -c %%Y $s` ]; done' % (
                      boot_dirs, self.scratch)])[0]
             if boot_affected:
                 adtlog.info('rebooting testbed after setup commands that affected boot')
@@ -581,7 +581,7 @@ class Testbed:
                     return True
         return False
 
-    def _run_apt_install(self, what, prefix, recommends):
+    def _run_apt_install(self, what, prefix, recommends, ignorerc=False):
         '''actually run apt-get install'''
 
         # capture status-fd to stderr
@@ -593,7 +593,7 @@ class Testbed:
                                       '-o Debug::pkgProblemResolver=true 3>&2 2>&1' %
                                       (prefix, what, recommends)],
                                      kind='install', stderr=subprocess.PIPE)
-        if rc != 0:
+        if not ignorerc and rc != 0:
             adtlog.debug('apt-get install %s failed; status-fd:\n%s' % (what, serr))
             # check if apt failed during package download, which might be a
             # transient error, so retry
@@ -709,6 +709,13 @@ Description: satisfy autopkgtest test dependencies
                         self.check_exec(['/bin/sh', '-ec', 'rm -f /etc/apt/preferences.d/autopkgtest-default-release'])
                     continue
 
+                adtlog.warning('Test dependencies are unsatisfiable - calling '
+                               'apt install on test deps directly for further '
+                               'data about failing dependencies in test logs')
+                self._run_apt_install('--simulate ' + deps.replace(',', ''),
+                                      ' '.join(self.eatmydata_prefix),
+                                      recommends, ignorerc=True)
+
                 if shell_on_failure:
                     self.run_shell()
                 if self.enable_apt_fallback:
@@ -850,7 +857,7 @@ Description: satisfy autopkgtest test dependencies
                        'which will only work for some packages')
 
         # download and unpack all debs
-        script = '''d=%(t)s/deps
+        script = r'''d=%(t)s/deps
 mkdir -p $d; cd $d
 apt-get download %(pkgs)s >&2
 for p in *.deb; do dpkg-deb --extract $p .; rm $p; done
@@ -1367,7 +1374,7 @@ fi
         if self.default_release is None:
 
             script = 'SRCS=$(ls /etc/apt/sources.list /etc/apt/sources.list.d/*.list 2>/dev/null|| true); '
-            script += '''sed -rn '/^(deb|deb-src) +(\[.*\] *)?(http|https|file):/ { s/\[.*\] +//; s/^[^ ]+ +[^ ]* +([^ -]+) +.*$/\\1/p }' $SRCS | head -n1'''
+            script += r'''sed -rn '/^(deb|deb-src) +(\[.*\] *)?(http|https|file):/ { s/\[.*\] +//; s/^[^ ]+ +[^ ]* +([^ -]+) +.*$/\1/p }' $SRCS | head -n1'''
             self.default_release = self.check_exec(['sh', '-ec', script], stdout=True).strip()
 
         return self.default_release
@@ -1477,6 +1484,10 @@ class TempPath(Path):
 
     These are only guaranteed to exit within one testbed run.
     '''
+
+    # private; used to make sure the names of autocleaned files don't collide
+    _filename_prefix = 1
+
     def __init__(self, testbed, name, is_dir=False, autoclean=True):
         '''Create a temporary Path object.
 
@@ -1500,6 +1511,10 @@ class TempPath(Path):
         else:
             host = testbed.output_dir
         self.autoclean = autoclean
+        if autoclean:
+            name = str(self._filename_prefix) + '-' + name
+            TempPath._filename_prefix += 1
+
         Path.__init__(self, testbed, os.path.join(host, name),
                       os.path.join(testbed.scratch, name),
                       is_dir)
