@@ -285,6 +285,13 @@ for details.'''
                          'that should provide the packages that are not pinned. For '
                          'Debian and Ubuntu, this is normally automatically detected '
                          'from the first entry in /etc/apt/sources.list.')
+    g_setup.add_argument('--no-apt-fallback',
+                         dest='enable_apt_fallback',
+                         action='store_false',
+                         default=True,
+                         help='Disable the apt fallback which is used with --apt-pocket or '
+                         '--pin-packages in case installation of dependencies fails due to '
+                         'strict pinning')
     g_setup.add_argument('--copy', metavar='HOSTFILE:TESTBEDFILE',
                          action='append', default=[],
                          help='Copy file or dir from host into testbed after '
@@ -338,14 +345,6 @@ for details.'''
     g_misc.add_argument('--build-parallel', metavar='N',
                         help='Set "parallel=N" DEB_BUILD_OPTION for building '
                         'packages (default: number of available processors)')
-    g_misc.add_argument(
-        '--no-apt-fallback',
-        dest='enable_apt_fallback',
-        action='store_false',
-        default=True,
-        help='Disable the apt fallback which is used with --apt-pocket or '
-             '--pin-packages in case installation of dependencies fails due to '
-             'strict pinning')
     g_misc.add_argument(
         '-h', '--help', action='help', default=argparse.SUPPRESS,
         help='show this help message and exit')
